@@ -60,9 +60,7 @@ class Model:
             result = []
             metrics = Counter()
             for item in response:
-                if self.options.show_pruned or (self.options.show_pruned is False and
-                                                self.options.only_show_pruned is False and item["pruned"] is False) or\
-                        (self.options.only_show_pruned and item["pruned"] is True):
+                if utils.check_condition_to_get_model(self.options, item):
                     if self.options.scores is not None or self.options.avg_scores:
                         new_scores = {}
                         total_score = 0
@@ -436,6 +434,25 @@ class Model:
                                           directory=self.options.directory)
         return res
 
+    def prune(self):
+        launcher.LOGGER.info("Pruning model %s:" % self.options.model)
+        confirm = launcher.confirm()
+        prune_model_count = 0
+        if confirm:
+            data = json.dumps({"include_released": self.options.include_released})
+            r = requests.post(os.path.join(self.options.url, "model/prune", self.options.model), data=data,
+                              auth=self.auth)
+            if r.status_code == 200:
+                prune_model_count += 1
+                launcher.LOGGER.info("Model has been pruned: %s" % self.options.model)
+            else:
+                launcher.LOGGER.error('Cannot prune model %s: %s' % (self.options.model, r.text))
+        else:
+            launcher.LOGGER.info("  ... skipping")
+
+        res = "%d model(s) pruned" % prune_model_count
+        return res
+
     def execute_command(self):
         result = None
         if self.options.subcmd == "list":
@@ -462,4 +479,6 @@ class Model:
             result = self.removeopen()
         if self.options.subcmd == "detail":
             result = self.detail()
+        if self.options.subcmd == "prune":
+            result = self.prune()
         return result
