@@ -13,6 +13,7 @@ import client.launcher as launcher
 from lib import utils
 
 launcher.LOGGER = logging.getLogger()
+CORPUS_SUFFIX = (".txt", ".tmx")
 
 
 class Task:
@@ -170,7 +171,7 @@ class Task:
                         assert p != -1, "language suffix should end filename %s" % filename
                         if src_lang is None:
                             src_lang = filename[p + 1:]
-                        else:
+                        elif not filename.endswith(CORPUS_SUFFIX):
                             assert src_lang == filename[p + 1:], \
                                 "incompatible language suffix in filename %s" % filename
                         if tgt_lang is None:
