@@ -93,6 +93,8 @@ def define_option():
                                     help='display pruned and not pruned models')
     parser_list_models.add_argument('--only_show_pruned', action='store_true',
                                     help='only display pruned models')
+    parser_list_models.add_argument('--only_show_released', action='store_true',
+                                    help='only display released models')
 
     parser_get_model = subparsers_model.add_parser('get', help='download the model')
     parser_get_model.add_argument('model', help='model')
@@ -168,6 +170,12 @@ def define_option():
     parser_removeopen_model.add_argument('-m', '--model', help='model', required=True)
     parser_removeopen_model.add_argument('-e', '--entity_code', help='2-letters entity code', required=True)
 
+    parser_prune_model = subparsers_model.add_parser('prune', help='{pm} prune a model')
+    launcher.shortcut_map["pm"] = ["model", "prune"]
+    parser_prune_model.add_argument('model', help='model', )
+    parser_prune_model.add_argument('--include_released', action='store_true',
+                                    help='prune the specified model, even if the model has already been released')
+
     subparsers_docker = launcher.subparsers_map["docker"].add_subparsers(help='sub-command help',
                                                                          dest='subcmd')
     subparsers_docker.required = True
@@ -286,6 +294,8 @@ def define_option():
                                         help="disable automatic test file translations")
     launcher.parser_launch.add_argument('--novalidschema', '--no_valid_schema', action='store_true',
                                         help='skip config validation')
+    launcher.parser_launch.add_argument('--not_patch_envvar', action='store_true',
+                                        help='do not auto patch storage environment variables')
     launcher.parser_launch.add_argument('--upgrade', choices=['auto', 'none', 'force'],
                                         default='auto',
                                         help='choice to upgrade when later docker image available:'
