@@ -16,6 +16,7 @@ import client.launcher as launcher
 _reqcache = {}
 lookup_cache = {}
 test_storages = None
+CORPUS_SUFFIX = (".txt", ".tmx")
 
 launcher.LOGGER = logging.getLogger()
 
@@ -236,8 +237,14 @@ def _lookup_repository(url, auth, service, remote_path, entity):
     result = r.json()
     if r.status_code != 200:
         return False, (r.status_code, result['message'])
-    lookup_cache[id] = [type(r) == dict and r.get('key') or fileObj.get('key')
-                        for fileObj in result]
+
+    lookup_cache[id] = []
+    for fileObj in result:
+        if fileObj.get('alias_names') and isinstance(fileObj['alias_names'], list):
+            lookup_cache[id].extend(fileObj['alias_names'])
+        elif fileObj.get('key'):
+            lookup_cache[id].append(fileObj['key'])
+
     return True, lookup_cache[id]
 
 
@@ -274,6 +281,13 @@ def _get_testfiles(url, auth, service, path, model, src_lang, tgt_lang):
                         ("%s:%s" % (storage_name, f), "pn9_testtrans:" +
                             model + "/" + storage_name + "/" + real_path + "/" + test_name + "." + tgt_lang))
                     count += 1
+                if f.endswith(CORPUS_SUFFIX):
+                    test_parts = f.split('/')
+                    test_name = test_parts[len(test_parts) - 1]
+                    res.append(
+                        ("%s:%s.%s" % (storage_name, f, src_lang), "pn9_testtrans:" +
+                         model + "/" + storage_name + "/" + real_path + "/" + test_name + "."+src_lang+'.' + tgt_lang))
+                    count += 1
             if entity == "CONF_DEFAULT":
                 entity = ""
             launcher.LOGGER.info('found %d test files in %s (entity "%s")' %
@@ -462,7 +476,7 @@ def merge_config(a, b):
     """Merges config b in a."""
     if isinstance(a, dict):
         for k, v in six.iteritems(b):
-            if k in a and isinstance(v, dict) and type(a[k]) == type(v):
+            if k in a and isinstance(v, dict) and type(a[k]) is type(v):
                 merge_config(a[k], v)
             else:
                 a[k] = v
@@ -514,7 +528,11 @@ def parse_version_number(image):
         version_main_number = 0
     else:
         version_main_number = int(current_version_pattern[q + 1:])
-    return (current_version_pattern, version_main_number)
+
+    i = image.find(":")
+    tag = image[i + 1:]
+    image_name = image[:i]
+    return current_version_pattern, version_main_number, image_name, tag
 
 
 # Check upgrades for docker image and return upgraded version if available and accepted by user
@@ -616,3 +634,38 @@ def get_schema_errors(schema, config):
         else:
             all_errors += '\n - In the option ' + error_path + ', ' + error_message
     return all_errors
+
+
+def is_released_model(input_model):
+    check_release = False
+    check_push = False
+    if input_model.get('releases'):
+        for k, v in input_model['releases'].items():
+            if k == 'unknown_task' or v.get('state') == 'completed' or v.get('state') == 'in progress':
+                check_release = True
+                break
+    if not check_release and input_model.get('push'):
+        for push in input_model['push']:
+            if not push.get('error'):
+                check_push = True
+                break
+        if not check_push and input_model.get('state') == 'deploying':
+            check_push = True
+    if check_release or check_push:
+        return True
+
+    return False
+
+
+def check_condition_to_get_model(options, model):
+    if options.show_pruned:
+        return True
+    elif options.only_show_pruned and model.get("pruned"):
+        return True
+    elif options.only_show_released and is_released_model(model):
+        return True
+    elif not options.show_pruned and not options.only_show_released and \
+            not options.only_show_pruned and not model["pruned"]:
+        return True
+
+    return False
